View source: R/set_gitlab_ci.R
| set_gitlab_ci | R Documentation |
Copies the .gitlab-ci.yml file provided by the shiny2docker package
into the specified directory. The GitLab CI configuration is designed to build a Docker image
and push the created image to the GitLab container registry.
set_gitlab_ci(path, tags = NULL)
path |
A character string specifying the directory where the
|
tags |
Optional character vector of GitLab runner tags. If provided, the function will add these tags to the generated CI job so the appropriate runner is selected. You can provide multiple tags. |
A logical value indicating whether the file was successfully copied (TRUE)
or not (FALSE).
# Copy the .gitlab-ci.yml file to a temporary directory
set_gitlab_ci(path = tempdir())
# Copy the file and specify runner tags
set_gitlab_ci(path = tempdir(), tags = c("shiny_build", "prod"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.